@@ -123,7 +123,7 @@ ExportCertificateCommand::ExportCertificateCommand(QAbstractItemView *v, KeyList
 }
 
 ExportCertificateCommand::ExportCertificateCommand(const Key &key)
-    : Command(key, new Private(this, 0))
+    : Command(key, new Private(this, nullptr))
 {
 
 }
@@ -252,7 +252,8 @@ void ExportCertificateCommand::Private::startExportJob(GpgME::Protocol protocol,
             q, &Command::progress);
 
     QStringList fingerprints;
-    Q_FOREACH (const Key &i, keys) {
+    fingerprints.reserve(keys.size());
+    for (const Key &i : keys) {
         fingerprints << QLatin1String(i.primaryFingerprint());
     }
 
