@@ -79,7 +79,7 @@ class ResultDialog : public QDialog
 {
     Q_OBJECT
 public:
-    ResultDialog(const QStringList &created, const QStringList &errors, QWidget *parent = Q_NULLPTR, Qt::WindowFlags f = 0)
+    ResultDialog(const QStringList &created, const QStringList &errors, QWidget *parent = nullptr, Qt::WindowFlags f = nullptr)
         : QDialog(parent, f),
           createdLB(created.empty()
                     ? i18nc("@info", "No checksum files have been created.")
@@ -237,7 +237,7 @@ private:
         q->bringToForeground(dlg);
         if (!errors.empty())
             q->setLastError(gpg_error(GPG_ERR_GENERAL),
-                            errors.join(QStringLiteral("\n")));
+                            errors.join(QLatin1Char('\n')));
         q->emitDoneOrError();
     }
     void slotProgress(int current, int total, const QString &what)
@@ -386,7 +386,7 @@ struct Dir {
 static QStringList remove_checksum_files(QStringList l, const QList<QRegExp> &rxs)
 {
     QStringList::iterator end = l.end();
-    Q_FOREACH (const QRegExp &rx, rxs) {
+    for (const QRegExp &rx : rxs) {
         end = std::remove_if(l.begin(), end,
                              [rx](const QString &str) { 
                                 return rx.exactMatch(str);
@@ -410,7 +410,7 @@ static QString decode(const QString &encoded)
     QString decoded;
     decoded.reserve(encoded.size());
     bool shift = false;
-    Q_FOREACH (QChar ch, encoded)
+    for (QChar ch : encoded)
         if (shift) {
             switch (ch.toLatin1()) {
             case '\\': decoded += QLatin1Char('\\'); break;
@@ -457,7 +457,7 @@ static std::vector<File> parse_sum_file(const QString &fileName)
 static quint64 aggregate_size(const QDir &dir, const QStringList &files)
 {
     quint64 n = 0;
-    Q_FOREACH (const QString &file, files) {
+    for (const QString &file : files) {
         n += QFileInfo(dir.absoluteFilePath(file)).size();
     }
     return n;
@@ -466,12 +466,15 @@ static quint64 aggregate_size(const QDir &dir, const QStringList &files)
 static std::shared_ptr<ChecksumDefinition> filename2definition(const QString &fileName,
         const std::vector< std::shared_ptr<ChecksumDefinition> > &checksumDefinitions)
 {
-    Q_FOREACH (const std::shared_ptr<ChecksumDefinition> &cd, checksumDefinitions)
-        if (cd)
-            Q_FOREACH (const QString &pattern, cd->patterns())
+    for (const std::shared_ptr<ChecksumDefinition> &cd : checksumDefinitions) {
+        if (cd) {
+            Q_FOREACH (const QString &pattern, cd->patterns()) {
                 if (QRegExp(pattern, fs_cs).exactMatch(fileName)) {
                     return cd;
                 }
+            }
+        }
+    }
     return std::shared_ptr<ChecksumDefinition>();
 }
 
@@ -487,7 +490,7 @@ static std::vector<Dir> find_dirs_by_sum_files(const QStringList &files, bool al
 
     int i = 0;
 
-    Q_FOREACH (const QString &file, files) {
+    for (const QString &file : files) {
 
         const QFileInfo fi(file);
         const QDir dir = fi.dir();
@@ -682,7 +685,7 @@ void CreateChecksumsController::Private::run()
                                   ? find_dirs_by_sum_files(files, allowAddition, progressCb, checksumDefinitions)
                                   : find_dirs_by_input_files(files, checksumDefinition, allowAddition, progressCb, checksumDefinitions);
 
-    Q_FOREACH (const Dir &dir, dirs) {
+    for (const Dir &dir : dirs) {
         qCDebug(KLEOPATRA_LOG) << dir;
     }
 
