@@ -70,8 +70,8 @@ public:
         NumModes
     };
 
-    explicit EncryptEMailController(Mode mode, QObject *parent = Q_NULLPTR);
-    explicit EncryptEMailController(const std::shared_ptr<ExecutionContext> &xc, Mode mode, QObject *parent = Q_NULLPTR);
+    explicit EncryptEMailController(Mode mode, QObject *parent = nullptr);
+    explicit EncryptEMailController(const std::shared_ptr<ExecutionContext> &xc, Mode mode, QObject *parent = nullptr);
     ~EncryptEMailController();
 
     Mode mode() const;
