@@ -41,8 +41,6 @@
 
 #include <Libkleo/Stl_Util>
 
-#include <boost/mem_fn.hpp>
-
 #include <KLocalizedString>
 
 #include <QCheckBox>
@@ -59,7 +57,6 @@ static const int ProgressBarHideDelay = 2000; // 2 secs
 using namespace Kleo;
 using namespace Kleo::Crypto;
 using namespace Kleo::Crypto::Gui;
-using namespace boost;
 
 class NewResultPage::Private
 {
@@ -68,20 +65,18 @@ public:
     explicit Private(NewResultPage *qq);
 
     void progress(const QString &msg, int progress, int total);
-    void result(const shared_ptr<const Task::Result> &result);
-    void started(const shared_ptr<Task> &result);
+    void result(const std::shared_ptr<const Task::Result> &result);
+    void started(const std::shared_ptr<Task> &result);
     void allDone();
-    void keepOpenWhenDone(bool keep);
     QLabel *labelForTag(const QString &tag);
 
-    std::vector< shared_ptr<TaskCollection> > m_collections;
+    std::vector< std::shared_ptr<TaskCollection> > m_collections;
     QTimer m_hideProgressTimer;
     QProgressBar *m_progressBar;
     QHash<QString, QLabel *> m_progressLabelByTag;
     QVBoxLayout *m_progressLabelLayout;
     int m_lastErrorItemIndex;
     ResultListWidget *m_resultList;
-    QCheckBox *m_keepOpenCB;
 };
 
 NewResultPage::Private::Private(NewResultPage *qq) : q(qq), m_lastErrorItemIndex(0)
@@ -98,11 +93,6 @@ NewResultPage::Private::Private(NewResultPage *qq) : q(qq), m_lastErrorItemIndex
     m_resultList = new ResultListWidget;
     connect(m_resultList, &ResultListWidget::linkActivated, q, &NewResultPage::linkActivated);
     layout->addWidget(m_resultList, 1);
-    m_keepOpenCB = new QCheckBox;
-    m_keepOpenCB->setText(i18n("Keep open after operation completed"));
-    m_keepOpenCB->setChecked(true);
-    connect(m_keepOpenCB, &QAbstractButton::toggled, q, &NewResultPage::keepOpenWhenDone);
-    layout->addWidget(m_keepOpenCB);
 
     connect(&m_hideProgressTimer, &QTimer::timeout, m_progressBar, &QProgressBar::hide);
 }
@@ -110,27 +100,10 @@ NewResultPage::Private::Private(NewResultPage *qq) : q(qq), m_lastErrorItemIndex
 void NewResultPage::Private::progress(const QString &msg, int progress, int total)
 {
     Q_UNUSED(msg);
-    // FIXME as of 07 2016 GpgME / GnuPG's progress is broken.
-    // Older versions overflow for files larger 2^31 bytes
-    // GnuPG 2.1.14 does not overflow but scales down the progress
-    // after more then 1024*1024 bytes are processed. Which is nearly
-    // unhandable. Total is always zero unless the job is completed
-    // for QGpgME as it internally uses memory based dataproviders
-    // and without the patch in https://bugs.gnupg.org/gnupg/issue2368
-    // has no way to handle this.
-    //
-    // See BKO #365931
-    if (progress && progress == total) {
-        m_progressBar->setRange(0, 1);
-        m_progressBar->setValue(1);
-    } else {
-        m_progressBar->setRange(0, 0);
-        m_progressBar->setValue(0);
-    }
-}
-
-void NewResultPage::Private::keepOpenWhenDone(bool)
-{
+    Q_ASSERT(progress >= 0);
+    Q_ASSERT(total >= 0);
+    m_progressBar->setRange(0, total);
+    m_progressBar->setValue(progress);
 }
 
 void NewResultPage::Private::allDone()
@@ -141,8 +114,6 @@ void NewResultPage::Private::allDone()
     }
     m_progressBar->setRange(0, 100);
     m_progressBar->setValue(100);
-    const bool errorOccurred =
-        kdtools::any(m_collections, mem_fn(&TaskCollection::errorOccurred));
     m_collections.clear();
     Q_FOREACH (const QString &i, m_progressLabelByTag.keys()) {
         if (!i.isEmpty()) {
@@ -155,19 +126,14 @@ void NewResultPage::Private::allDone()
         cancel->setEnabled(false);
     }
     Q_EMIT q->completeChanged();
-    if (!m_keepOpenCB->isChecked() && !errorOccurred)
-        if (QWizard *wiz = q->wizard())
-            if (QAbstractButton *btn = wiz->button(QWizard::FinishButton)) {
-                QTimer::singleShot(500, btn, SLOT(animateClick()));
-            }
     m_hideProgressTimer.start();
 }
 
-void NewResultPage::Private::result(const shared_ptr<const Task::Result> &)
+void NewResultPage::Private::result(const std::shared_ptr<const Task::Result> &)
 {
 }
 
-void NewResultPage::Private::started(const shared_ptr<Task> &task)
+void NewResultPage::Private::started(const std::shared_ptr<Task> &task)
 {
     assert(task);
     const QString tag = task->tag();
@@ -189,34 +155,16 @@ NewResultPage::~NewResultPage()
 {
 }
 
-bool NewResultPage::keepOpenWhenDone() const
-{
-    return d->m_keepOpenCB->isChecked();
-}
-
-void NewResultPage::setKeepOpenWhenDone(bool keep)
-{
-    d->m_keepOpenCB->setChecked(keep);
-}
-
-void NewResultPage::setKeepOpenWhenDoneShown(bool on)
-{
-    d->m_keepOpenCB->setVisible(on);
-    if (!on) {
-        d->m_keepOpenCB->setChecked(true);
-    }
-}
-
-void NewResultPage::setTaskCollection(const shared_ptr<TaskCollection> &coll)
+void NewResultPage::setTaskCollection(const std::shared_ptr<TaskCollection> &coll)
 {
     //clear(); ### PENDING(marc) implement
     addTaskCollection(coll);
 }
 
-void NewResultPage::addTaskCollection(const shared_ptr<TaskCollection> &coll)
+void NewResultPage::addTaskCollection(const std::shared_ptr<TaskCollection> &coll)
 {
     assert(coll);
-    if (kdtools::contains(d->m_collections, coll)) {
+    if (std::find(d->m_collections.cbegin(), d->m_collections.cend(), coll) != d->m_collections.cend()) {
         return;
     }
     d->m_hideProgressTimer.stop();
@@ -227,12 +175,12 @@ void NewResultPage::addTaskCollection(const shared_ptr<TaskCollection> &coll)
             this, SLOT(progress(QString,int,int)));
     connect(coll.get(), SIGNAL(done()),
             this, SLOT(allDone()));
-    connect(coll.get(), SIGNAL(result(boost::shared_ptr<const Kleo::Crypto::Task::Result>)),
-            this, SLOT(result(boost::shared_ptr<const Kleo::Crypto::Task::Result>)));
-    connect(coll.get(), SIGNAL(started(boost::shared_ptr<Kleo::Crypto::Task>)),
-            this, SLOT(started(boost::shared_ptr<Kleo::Crypto::Task>)));
+    connect(coll.get(), SIGNAL(result(std::shared_ptr<const Kleo::Crypto::Task::Result>)),
+            this, SLOT(result(std::shared_ptr<const Kleo::Crypto::Task::Result>)));
+    connect(coll.get(), SIGNAL(started(std::shared_ptr<Kleo::Crypto::Task>)),
+            this, SLOT(started(std::shared_ptr<Kleo::Crypto::Task>)));
 
-    Q_FOREACH (const shared_ptr<Task> &i, coll->tasks()) {    // create labels for all tags in collection
+    Q_FOREACH (const std::shared_ptr<Task> &i, coll->tasks()) {    // create labels for all tags in collection
         assert(i);
         QLabel *l = d->labelForTag(i->tag());
         assert(l); (void)l;
