@@ -63,6 +63,8 @@
 #include "commands/detailscommand.h"
 #include "commands/newcertificatecommand.h"
 
+#include "dialogs/updatenotification.h"
+
 #include <KIconLoader>
 #include <KLocalizedString>
 #include "kleopatra_debug.h"
@@ -101,7 +103,8 @@ class KleopatraApplication::Private
 public:
     explicit Private(KleopatraApplication *qq)
         : q(qq),
-          ignoreNewInstance(true)
+          ignoreNewInstance(true),
+          sysTray(nullptr)
     {
     }
     ~Private() {
@@ -246,7 +249,7 @@ void KleopatraApplication::slotActivateRequested(const QStringList &arguments,
     }
 
     if (!err.isEmpty()) {
-        KMessageBox::sorry(NULL, err.toHtmlEscaped(), i18n("Failed to execute command"));
+        KMessageBox::sorry(nullptr, err.toHtmlEscaped(), i18n("Failed to execute command"));
         Q_EMIT setExitValue(1);
         return;
     }
@@ -311,7 +314,7 @@ QString KleopatraApplication::newInstance(const QCommandLineParser &parser,
         if (needle.isEmpty()) {
             return i18n("No search string specified for --search");
         }
-        LookupCertificatesCommand *const cmd = new LookupCertificatesCommand(needle, 0);
+        LookupCertificatesCommand *const cmd = new LookupCertificatesCommand(needle, nullptr);
         cmd->setParentWId(parentId);
         cmd->start();
         return QString();
@@ -331,7 +334,7 @@ QString KleopatraApplication::newInstance(const QCommandLineParser &parser,
 
     // Check for --gen-key command
     if (parser.isSet("gen-key")) {
-        auto cmd = new NewCertificateCommand(Q_NULLPTR);
+        auto cmd = new NewCertificateCommand(nullptr);
         cmd->setParentWId(parentId);
         cmd->setProtocol(protocol);
         cmd->start();
@@ -383,7 +386,7 @@ QString KleopatraApplication::newInstance(const QCommandLineParser &parser,
                 cmd->setParentWId(parentId);
                 cmd->start();
             }
-            return errors.join("\n");
+            return errors.join('\n');
         }
     }
 
@@ -487,6 +490,7 @@ void KleopatraApplication::openOrRaiseMainWindow()
         d->connectConfigureDialog();
     }
     open_or_raise(mw);
+    UpdateNotification::checkUpdate(mw);
 }
 
 void KleopatraApplication::openOrRaiseConfigDialog()
@@ -516,7 +520,7 @@ void KleopatraApplication::importCertificatesFromFile(const QStringList &files,
 
 void KleopatraApplication::encryptFiles(const QStringList &files, GpgME::Protocol proto)
 {
-    SignEncryptFilesCommand *const cmd = new SignEncryptFilesCommand(files, 0);
+    SignEncryptFilesCommand *const cmd = new SignEncryptFilesCommand(files, nullptr);
     cmd->setEncryptionPolicy(Force);
     cmd->setSigningPolicy(Allow);
     if (proto != GpgME::UnknownProtocol) {
@@ -527,7 +531,7 @@ void KleopatraApplication::encryptFiles(const QStringList &files, GpgME::Protoco
 
 void KleopatraApplication::signFiles(const QStringList &files, GpgME::Protocol proto)
 {
-    SignEncryptFilesCommand *const cmd = new SignEncryptFilesCommand(files, 0);
+    SignEncryptFilesCommand *const cmd = new SignEncryptFilesCommand(files, nullptr);
     cmd->setSigningPolicy(Force);
     cmd->setEncryptionPolicy(Deny);
     if (proto != GpgME::UnknownProtocol) {
@@ -538,7 +542,7 @@ void KleopatraApplication::signFiles(const QStringList &files, GpgME::Protocol p
 
 void KleopatraApplication::signEncryptFiles(const QStringList &files, GpgME::Protocol proto)
 {
-    SignEncryptFilesCommand *const cmd = new SignEncryptFilesCommand(files, 0);
+    SignEncryptFilesCommand *const cmd = new SignEncryptFilesCommand(files, nullptr);
     if (proto != GpgME::UnknownProtocol) {
         cmd->setProtocol(proto);
     }
@@ -547,21 +551,21 @@ void KleopatraApplication::signEncryptFiles(const QStringList &files, GpgME::Pro
 
 void KleopatraApplication::decryptFiles(const QStringList &files, GpgME::Protocol /*proto*/)
 {
-    DecryptVerifyFilesCommand *const cmd = new DecryptVerifyFilesCommand(files, 0);
+    DecryptVerifyFilesCommand *const cmd = new DecryptVerifyFilesCommand(files, nullptr);
     cmd->setOperation(Decrypt);
     cmd->start();
 }
 
 void KleopatraApplication::verifyFiles(const QStringList &files, GpgME::Protocol /*proto*/)
 {
-    DecryptVerifyFilesCommand *const cmd = new DecryptVerifyFilesCommand(files, 0);
+    DecryptVerifyFilesCommand *const cmd = new DecryptVerifyFilesCommand(files, nullptr);
     cmd->setOperation(Verify);
     cmd->start();
 }
 
 void KleopatraApplication::decryptVerifyFiles(const QStringList &files, GpgME::Protocol /*proto*/)
 {
-    DecryptVerifyFilesCommand *const cmd = new DecryptVerifyFilesCommand(files, 0);
+    DecryptVerifyFilesCommand *const cmd = new DecryptVerifyFilesCommand(files, nullptr);
     cmd->start();
 }
 
@@ -569,7 +573,7 @@ void KleopatraApplication::checksumFiles(const QStringList &files, GpgME::Protoc
 {
     QStringList verifyFiles, createFiles;
 
-    Q_FOREACH (const QString &file, files) {
+    for (const QString &file : files) {
         if (isChecksumFile(file)) {
             verifyFiles << file;
         } else {
@@ -578,11 +582,11 @@ void KleopatraApplication::checksumFiles(const QStringList &files, GpgME::Protoc
     }
 
     if (!verifyFiles.isEmpty()) {
-        auto *const cmd = new ChecksumVerifyFilesCommand(verifyFiles, 0);
+        auto *const cmd = new ChecksumVerifyFilesCommand(verifyFiles, nullptr);
         cmd->start();
     }
     if (!createFiles.isEmpty()) {
-        auto *const cmd = new ChecksumCreateFilesCommand(createFiles, 0);
+        auto *const cmd = new ChecksumCreateFilesCommand(createFiles, nullptr);
         cmd->start();
     }
 }
