@@ -39,6 +39,8 @@
 #include "view/tabwidget.h"
 #include "view/keylistcontroller.h"
 #include "view/keycacheoverlay.h"
+#include "view/smartcardwidget.h"
+#include "view/welcomewidget.h"
 
 #include "commands/selftestcommand.h"
 #include "commands/importcrlcommand.h"
@@ -52,6 +54,8 @@
 #include "utils/filedialog.h"
 #include "utils/clipboardmenu.h"
 
+#include "dialogs/updatenotification.h"
+
 #include <KXMLGUIFactory>
 #include <QApplication>
 #include <KActionCollection>
@@ -77,12 +81,14 @@
 #include <QProcess>
 #include <QVBoxLayout>
 #include <QMimeData>
+#include <QDesktopWidget>
 
 #include <Libkleo/KeyListModel>
 #include <Libkleo/KeyListSortFilterProxyModel>
 #include <libkleo/cryptoconfigdialog.h>
 #include <Libkleo/Stl_Util>
 #include <Libkleo/Classify>
+#include <Libkleo/KeyCache>
 #include <QGpgME/CryptoConfig>
 #include <QGpgME/Protocol>
 
@@ -193,6 +199,11 @@ public:
                                i18n("Error Starting KWatchGnuPG"));
     }
 
+    void forceUpdateCheck()
+    {
+        UpdateNotification::checkUpdate(q, true);
+    }
+
     void slotConfigCommitted();
     void slotContextMenuRequested(QAbstractItemView *, const QPoint &p)
     {
@@ -203,17 +214,25 @@ public:
         }
     }
 
-    void aboutGpg4Win()
-    {
-        (new KAboutApplicationDialog(AboutGpg4WinData(),
-                                     KAboutApplicationDialog::HideKdeVersion|KAboutApplicationDialog::HideTranslators,
-                                     q))->show();
-    }
     void slotFocusQuickSearch()
     {
         ui.searchBar->lineEdit()->setFocus();
     }
 
+    void toggleSmartcardView()
+    {
+        if (ui.scWidget->isVisible()) {
+            ui.scWidget->hide();
+            ui.searchBar->show();
+            ui.tabWidget.show();
+        } else {
+            ui.scWidget->show();
+            ui.searchBar->hide();
+            ui.tabWidget.hide();
+            ui.welcomeWidget->hide();
+        }
+    }
+
 private:
     void setupActions();
 
@@ -222,6 +241,22 @@ private:
         return ui.tabWidget.currentView();
     }
 
+    void checkWelcomePage()
+    {
+        if (ui.scWidget->isVisible()) {
+           return;
+        }
+        if (KeyCache::instance()->keys().empty()) {
+            ui.searchBar->hide();
+            ui.tabWidget.hide();
+            ui.welcomeWidget->show();
+        } else {
+            ui.welcomeWidget->hide();
+            ui.searchBar->show();
+            ui.tabWidget.show();
+        }
+    }
+
 private:
     Kleo::KeyListController controller;
     bool firstShow : 1;
@@ -229,6 +264,8 @@ private:
 
         TabWidget tabWidget;
         SearchBar *searchBar;
+        SmartCardWidget *scWidget;
+        WelcomeWidget *welcomeWidget;
         explicit UI(MainWindow *q);
     } ui;
     QAction *focusToClickSearchAction;
@@ -250,6 +287,14 @@ MainWindow::Private::UI::UI(MainWindow *q)
     vbox->addWidget(&tabWidget);
     new KeyCacheOverlay(mainWidget, q);
 
+    scWidget = new SmartCardWidget();
+    vbox->addWidget(scWidget);
+    scWidget->hide();
+
+    welcomeWidget = new WelcomeWidget();
+    vbox->addWidget(welcomeWidget);
+    welcomeWidget->hide();
+
     q->setCentralWidget(mainWidget);
 }
 
@@ -277,6 +322,12 @@ MainWindow::Private::Private(MainWindow *qq)
     setupActions();
 
     connect(&controller, SIGNAL(contextMenuRequested(QAbstractItemView*,QPoint)), q, SLOT(slotContextMenuRequested(QAbstractItemView*,QPoint)));
+    connect(ui.scWidget, &SmartCardWidget::backRequested, q, [this]() {
+            auto action = q->actionCollection()->action(QStringLiteral("manage_smartcard"));
+            Q_ASSERT(action);
+            action->setChecked(false);
+        });
+    connect(KeyCache::instance().get(), &KeyCache::keyListingDone, q, [this] () {checkWelcomePage();});
 
     q->createGUI(QStringLiteral("kleopatra.rc"));
 
@@ -291,6 +342,7 @@ MainWindow::Private::~Private() {}
 MainWindow::MainWindow(QWidget *parent, Qt::WindowFlags flags)
     : KXmlGuiWindow(parent, flags), d(new Private(this))
 {
+    resize(960, 440);
 }
 
 MainWindow::~MainWindow() {}
@@ -308,6 +360,12 @@ void MainWindow::Private::setupActions()
             "tools_start_kwatchgnupg", i18n("GnuPG Log Viewer"), QString(),
             "kwatchgnupg", q, SLOT(gnupgLogViewer()), QString(), false, true
         },
+#endif
+#ifdef Q_OS_WIN
+        {
+            "help_check_updates", i18n("Check for updates"), QString(),
+            "gpg4win-compact", q, SLOT(forceUpdateCheck()), QString(), false, true
+        },
 #endif
         // most have been MOVED TO keylistcontroller.cpp
 #if 0
@@ -319,15 +377,13 @@ void MainWindow::Private::setupActions()
         // Settings menu
         {
             "settings_self_test", i18n("Perform Self-Test"), QString(),
-            0, q, SLOT(selfTest()), QString(), false, true
+            nullptr, q, SLOT(selfTest()), QString(), false, true
         },
-        // Help menu
-#ifdef Q_OS_WIN
         {
-            "help_about_gpg4win", i18n("About Gpg4win"), QString(),
-            "gpg4win-compact", q, SLOT(aboutGpg4Win()), QString(), false, true
-        },
-#endif
+            "manage_smartcard", i18n("Manage Smartcards"),
+            i18n("Edit or initialize a crypto hardware token."), "secure-card", q, SLOT(toggleSmartcardView()), QString(), true, true
+        }
+
         // most have been MOVED TO keylistcontroller.cpp
     };
 
@@ -511,13 +567,13 @@ void MainWindow::dropEvent(QDropEvent *e)
     QMenu menu;
 
     QAction *const signEncrypt = menu.addAction(i18n("Sign/Encrypt..."));
-    QAction *const decryptVerify = mayBeAnyMessageType(classification) ? menu.addAction(i18n("Decrypt/Verify...")) : 0;
+    QAction *const decryptVerify = mayBeAnyMessageType(classification) ? menu.addAction(i18n("Decrypt/Verify...")) : nullptr;
     if (signEncrypt || decryptVerify) {
         menu.addSeparator();
     }
 
-    QAction *const importCerts = mayBeAnyCertStoreType(classification) ? menu.addAction(i18n("Import Certificates")) : 0;
-    QAction *const importCRLs  = mayBeCertificateRevocationList(classification) ? menu.addAction(i18n("Import CRLs")) : 0;
+    QAction *const importCerts = mayBeAnyCertStoreType(classification) ? menu.addAction(i18n("Import Certificates")) : nullptr;
+    QAction *const importCRLs  = mayBeCertificateRevocationList(classification) ? menu.addAction(i18n("Import CRLs")) : nullptr;
     if (importCerts || importCRLs) {
         menu.addSeparator();
     }
